[![Git](https://git-scm.com/images/logo@2x.png)](https://git-scm.com/) --fast-version-control
![](https://git-scm.com/images/dark-mode.svg)
  * [About](https://git-scm.com/about)
    * [Trademark](https://git-scm.com/about/trademark)
  * [Learn](https://git-scm.com/learn)
    * [Book](https://git-scm.com/book)
    * [Cheat Sheet](https://git-scm.com/cheat-sheet)
    * [Videos](https://git-scm.com/videos)
    * [External Links](https://git-scm.com/doc/ext)
  * [Tools](https://git-scm.com/tools)
    * [Command Line](https://git-scm.com/tools/command-line)
    * [GUIs](https://git-scm.com/tools/guis)
    * [Hosting](https://git-scm.com/tools/hosting)
  * [Reference](https://git-scm.com/docs)
  * [Install](https://git-scm.com/install/linux)
  * [Community](https://git-scm.com/community)


  * Table of Contents
    * [NAME](https://git-scm.com/docs/gitk#_name)
    * [SYNOPSIS](https://git-scm.com/docs/gitk#_synopsis)
    * [DESCRIPTION](https://git-scm.com/docs/gitk#_description)
    * [OPTIONS](https://git-scm.com/docs/gitk#_options)
    * [Examples](https://git-scm.com/docs/gitk#_examples)
    * [Files](https://git-scm.com/docs/gitk#_files)
    * [History](https://git-scm.com/docs/gitk#_history)
    * [SEE ALSO](https://git-scm.com/docs/gitk#_see_also)
    * [GIT](https://git-scm.com/docs/gitk#_git)


[ English ▾](https://git-scm.com/docs/gitk)
Localized versions of **gitk** manual
  1. [English ](https://git-scm.com/docs/gitk)

Want to read in your language or fix typos?
[You can help translate this page](https://github.com/jnavila/git-manpages-l10n).
[Topics ▾](https://git-scm.com/docs/gitk)
### Setup and Config
  * [ git ](https://git-scm.com/docs/git)
  * [ config ](https://git-scm.com/docs/git-config)
  * [ help ](https://git-scm.com/docs/git-help)
  * [ bugreport ](https://git-scm.com/docs/git-bugreport)
  * [ Credential helpers ](https://git-scm.com/doc/credential-helpers)


### Getting and Creating Projects
  * [ init ](https://git-scm.com/docs/git-init)
  * [ clone ](https://git-scm.com/docs/git-clone)


### Basic Snapshotting
  * [ add ](https://git-scm.com/docs/git-add)
  * [ status ](https://git-scm.com/docs/git-status)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ commit ](https://git-scm.com/docs/git-commit)
  * [ notes ](https://git-scm.com/docs/git-notes)
  * [ restore ](https://git-scm.com/docs/git-restore)
  * [ reset ](https://git-scm.com/docs/git-reset)
  * [ rm ](https://git-scm.com/docs/git-rm)
  * [ mv ](https://git-scm.com/docs/git-mv)


### Branching and Merging
  * [ branch ](https://git-scm.com/docs/git-branch)
  * [ checkout ](https://git-scm.com/docs/git-checkout)
  * [ switch ](https://git-scm.com/docs/git-switch)
  * [ merge ](https://git-scm.com/docs/git-merge)
  * [ mergetool ](https://git-scm.com/docs/git-mergetool)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ stash ](https://git-scm.com/docs/git-stash)
  * [ tag ](https://git-scm.com/docs/git-tag)
  * [ worktree ](https://git-scm.com/docs/git-worktree)


### Sharing and Updating Projects
  * [ fetch ](https://git-scm.com/docs/git-fetch)
  * [ pull ](https://git-scm.com/docs/git-pull)
  * [ push ](https://git-scm.com/docs/git-push)
  * [ remote ](https://git-scm.com/docs/git-remote)
  * [ submodule ](https://git-scm.com/docs/git-submodule)


### Inspection and Comparison
  * [ show ](https://git-scm.com/docs/git-show)
  * [ log ](https://git-scm.com/docs/git-log)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ difftool ](https://git-scm.com/docs/git-difftool)
  * [ range-diff ](https://git-scm.com/docs/git-range-diff)
  * [ shortlog ](https://git-scm.com/docs/git-shortlog)
  * [ describe ](https://git-scm.com/docs/git-describe)


### Patching
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ cherry-pick ](https://git-scm.com/docs/git-cherry-pick)
  * [ diff ](https://git-scm.com/docs/git-diff)
  * [ rebase ](https://git-scm.com/docs/git-rebase)
  * [ revert ](https://git-scm.com/docs/git-revert)


### Debugging
  * [ bisect ](https://git-scm.com/docs/git-bisect)
  * [ blame ](https://git-scm.com/docs/git-blame)
  * [ grep ](https://git-scm.com/docs/git-grep)


### Email
  * [ am ](https://git-scm.com/docs/git-am)
  * [ apply ](https://git-scm.com/docs/git-apply)
  * [ imap-send ](https://git-scm.com/docs/git-imap-send)
  * [ format-patch ](https://git-scm.com/docs/git-format-patch)
  * [ send-email ](https://git-scm.com/docs/git-send-email)
  * [ request-pull ](https://git-scm.com/docs/git-request-pull)


### External Systems
  * [ svn ](https://git-scm.com/docs/git-svn)
  * [ fast-import ](https://git-scm.com/docs/git-fast-import)


### Server Admin
  * [ daemon ](https://git-scm.com/docs/git-daemon)
  * [ update-server-info ](https://git-scm.com/docs/git-update-server-info)


### Guides
  * [ gitattributes ](https://git-scm.com/docs/gitattributes)
  * [ Command-line interface conventions ](https://git-scm.com/docs/gitcli)
  * [ Everyday Git ](https://git-scm.com/docs/giteveryday)
  * [ Frequently Asked Questions (FAQ) ](https://git-scm.com/docs/gitfaq)
  * [ Glossary ](https://git-scm.com/docs/gitglossary)
  * [ Hooks ](https://git-scm.com/docs/githooks)
  * [ gitignore ](https://git-scm.com/docs/gitignore)
  * [ gitmodules ](https://git-scm.com/docs/gitmodules)
  * [ Revisions ](https://git-scm.com/docs/gitrevisions)
  * [ Submodules ](https://git-scm.com/docs/gitsubmodules)
  * [ Tutorial ](https://git-scm.com/docs/gittutorial)
  * [ Workflows ](https://git-scm.com/docs/gitworkflows)
  * [ All guides... ](https://git-scm.com/docs/git#_guides)


### Administration
  * [ clean ](https://git-scm.com/docs/git-clean)
  * [ gc ](https://git-scm.com/docs/git-gc)
  * [ fsck ](https://git-scm.com/docs/git-fsck)
  * [ reflog ](https://git-scm.com/docs/git-reflog)
  * [ filter-branch ](https://git-scm.com/docs/git-filter-branch)
  * [ instaweb ](https://git-scm.com/docs/git-instaweb)
  * [ archive ](https://git-scm.com/docs/git-archive)
  * [ bundle ](https://git-scm.com/docs/git-bundle)


### Plumbing Commands
  * [ cat-file ](https://git-scm.com/docs/git-cat-file)
  * [ check-ignore ](https://git-scm.com/docs/git-check-ignore)
  * [ checkout-index ](https://git-scm.com/docs/git-checkout-index)
  * [ commit-tree ](https://git-scm.com/docs/git-commit-tree)
  * [ count-objects ](https://git-scm.com/docs/git-count-objects)
  * [ diff-index ](https://git-scm.com/docs/git-diff-index)
  * [ for-each-ref ](https://git-scm.com/docs/git-for-each-ref)
  * [ hash-object ](https://git-scm.com/docs/git-hash-object)
  * [ ls-files ](https://git-scm.com/docs/git-ls-files)
  * [ ls-tree ](https://git-scm.com/docs/git-ls-tree)
  * [ merge-base ](https://git-scm.com/docs/git-merge-base)
  * [ read-tree ](https://git-scm.com/docs/git-read-tree)
  * [ rev-list ](https://git-scm.com/docs/git-rev-list)
  * [ rev-parse ](https://git-scm.com/docs/git-rev-parse)
  * [ show-ref ](https://git-scm.com/docs/git-show-ref)
  * [ symbolic-ref ](https://git-scm.com/docs/git-symbolic-ref)
  * [ update-index ](https://git-scm.com/docs/git-update-index)
  * [ update-ref ](https://git-scm.com/docs/git-update-ref)
  * [ verify-pack ](https://git-scm.com/docs/git-verify-pack)
  * [ write-tree ](https://git-scm.com/docs/git-write-tree)


[ Latest version ▾ ](https://git-scm.com/docs/gitk) gitk last updated in 2.51.1
Changes in the **gitk** manual
  1. 2.51.2 → 2.53.0 no changes
  2. [2.51.1 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-10-15_ ](https://git-scm.com/docs/gitk/2.51.1)
  3. [2.51.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2025-08-18_ ](https://git-scm.com/docs/gitk/2.51.0)
  4. 2.44.1 → 2.50.1 no changes
  5. [2.44.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2024-02-23_ ](https://git-scm.com/docs/gitk/2.44.0)
  6. 2.43.1 → 2.43.7 no changes
  7. [2.43.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2023-11-20_ ](https://git-scm.com/docs/gitk/2.43.0)
  8. 2.30.1 → 2.42.4 no changes
  9. [2.30.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-12-27_ ](https://git-scm.com/docs/gitk/2.30.0)
  10. 2.25.1 → 2.29.3 no changes
  11. [2.25.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2020-01-13_ ](https://git-scm.com/docs/gitk/2.25.0)
  12. 2.22.1 → 2.24.4 no changes
  13. [2.22.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2019-06-07_ ](https://git-scm.com/docs/gitk/2.22.0)
  14. 2.18.1 → 2.21.4 no changes
  15. [2.18.0 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2018-06-21_ ](https://git-scm.com/docs/gitk/2.18.0)
  16. 2.13.7 → 2.17.6 no changes
  17. [2.12.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/gitk/2.12.5)
  18. 2.11.4 no changes
  19. [2.10.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-09-22_ ](https://git-scm.com/docs/gitk/2.10.5)
  20. [2.9.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2017-07-30_ ](https://git-scm.com/docs/gitk/2.9.5)
  21. 2.4.12 → 2.8.6 no changes
  22. [2.3.10 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2015-09-28_ ](https://git-scm.com/docs/gitk/2.3.10)
  23. 2.2.3 no changes
  24. [2.1.4 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/gitk/2.1.4)
  25. [2.0.5 ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/green-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/red-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) ![](https://git-scm.com/images/icons/grey-dot.png) _2014-12-17_ ](https://git-scm.com/docs/gitk/2.0.5)


Check your version of git by running
`git --version`
##  [](https://git-scm.com/docs/gitk#_name)NAME
gitk - The Git repository browser
##  [](https://git-scm.com/docs/gitk#_synopsis)SYNOPSIS
```
_gitk_ [<options>] [<revision-range>] [--] [<path>…​]
```

##  [](https://git-scm.com/docs/gitk#_description)DESCRIPTION
Displays changes in a repository or a selected set of commits. This includes visualizing the commit graph, showing information related to each commit, and the files in the trees of each revision.
##  [](https://git-scm.com/docs/gitk#_options)OPTIONS
To control which revisions to show, gitk supports most options applicable to the _git rev-list_ command. It also supports a few options applicable to the _git diff-*_ commands to control how the changes each commit introduces are shown. Finally, it supports some gitk-specific options.
gitk generally only understands options with arguments in the _stuck_ form (see [gitcli[7]](https://git-scm.com/docs/gitcli)) due to limitations in the command-line parser.
###  [](https://git-scm.com/docs/gitk#_rev_list_options_and_arguments)rev-list options and arguments
This manual page describes only the most frequently used options. See [git-rev-list[1]](https://git-scm.com/docs/git-rev-list) for a complete list.

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt---all)--all

Show all refs (branches, tags, etc.).

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt---branchespattern)--branches[=<pattern>]


[](https://git-scm.com/docs/gitk#Documentation/gitk.txt---tagspattern)--tags[=<pattern>]


[](https://git-scm.com/docs/gitk#Documentation/gitk.txt---remotespattern)--remotes[=<pattern>]

Pretend as if all the branches (tags, remote branches, resp.) are listed on the command line as _< commit>_. If _< pattern>_ is given, limit refs to ones matching given shell glob. If pattern lacks _?_ , _*_ , or _[_ , _/*_ at the end is implied.

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt---sincedate)--since=<date>

Show commits more recent than a specific date.

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt---untildate)--until=<date>

Show commits older than a specific date.

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt---date-order)--date-order

Sort commits by date when possible.

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt---merge)--merge

After an attempt to merge stops with conflicts, show the commits on the history between two branches (i.e. the HEAD and the MERGE_HEAD) that modify the conflicted files and do not exist on all the heads being merged.

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt---left-right)--left-right

Mark which side of a symmetric difference a commit is reachable from. Commits from the left side are prefixed with a _<_ symbol and those from the right with a _>_ symbol.

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt---full-history)--full-history

When filtering history with _< path>…​_, does not prune some history. (See "History simplification" in [git-log[1]](https://git-scm.com/docs/git-log) for a more detailed explanation.)

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt---simplify-merges)--simplify-merges

Additional option to `--full-history` to remove some needless merges from the resulting history, as there are no selected commits contributing to this merge. (See "History simplification" in [git-log[1]](https://git-scm.com/docs/git-log) for a more detailed explanation.)

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt---ancestry-path)--ancestry-path

When given a range of commits to display (e.g. _commit1..commit2_ or _commit2 ^commit1_), only display commits that exist directly on the ancestry chain between the _commit1_ and _commit2_ , i.e. commits that are both descendants of _commit1_ , and ancestors of _commit2_. (See "History simplification" in [git-log[1]](https://git-scm.com/docs/git-log) for a more detailed explanation.)

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt--Lstartendfile)`-L`_< start>_`,`_< end>_`:`_< file>_


[](https://git-scm.com/docs/gitk#Documentation/gitk.txt--Lfuncnamefile)`-L:`_< funcname>_`:`_< file>_

Trace the evolution of the line range given by _< start>_`,`_< end>_, or by the function name regex _< funcname>_, within the _< file>_. You may not give any pathspec limiters. This is currently limited to a walk starting from a single revision, i.e., you may only give zero or one positive revision arguments, and _< start>_ and _< end>_ (or _< funcname>_) must exist in the starting revision. You can specify this option more than once. Implies `--patch`. Patch output can be suppressed using `--no-patch`, but other diff formats (namely `--raw`, `--numstat`, `--shortstat`, `--dirstat`, `--summary`, `--name-only`, `--name-status`, `--check`) are not currently implemented.
_< start>_ and _< end>_ can take one of these forms:
  * _< number>_
If _< start>_ or _< end>_ is a number, it specifies an absolute line number (lines count from 1).
  * `/`_< regex>_`/`
This form will use the first line matching the given POSIX _< regex>_. If _< start>_ is a regex, it will search from the end of the previous `-L` range, if any, otherwise from the start of file. If _< start>_ is `^/`_< regex>_`/`, it will search from the start of file. If _< end>_ is a regex, it will search starting at the line given by _< start>_.
  * `+`_< offset>_ or `-`_< offset>_
This is only valid for _< end>_ and will specify a number of lines before or after the line given by _< start>_.


If `:`_< funcname>_ is given in place of _< start>_ and _< end>_, it is a regular expression that denotes the range from the first funcname line that matches _< funcname>_, up to the next funcname line. `:`_< funcname>_ searches from the end of the previous `-L` range, if any, otherwise from the start of file. `^:`_< funcname>_ searches from the start of file. The function names are determined in the same way as `git` `diff` works out patch hunk headers (see _Defining a custom hunk-header_ in [gitattributes[5]](https://git-scm.com/docs/gitattributes)).

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt-revisionrange)<revision range>

Limit the revisions to show. This can be either a single revision meaning show from the given revision and back, or it can be a range in the form "_< from>_.._< to>_" to show all revisions between _< from>_ and back to _< to>_. Note, more advanced revision selection can be applied. For a more complete list of ways to spell object names, see [gitrevisions[7]](https://git-scm.com/docs/gitrevisions).

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt-path)<path>…​

Limit commits to the ones touching files in the given paths. Note, to avoid ambiguity with respect to revision names use "--" to separate the paths from any preceding options.
###  [](https://git-scm.com/docs/gitk#_gitk_specific_options)gitk-specific options

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt---argscmdcommand)--argscmd=<command>

Command to be run each time gitk has to determine the revision range to show. The command is expected to print on its standard output a list of additional revisions to be shown, one per line. Use this instead of explicitly specifying a _< revision-range>_ if the set of commits to show may vary between refreshes.

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt---select-commitref)--select-commit=<ref>

Select the specified commit after loading the graph. Default behavior is equivalent to specifying _--select-commit=HEAD_.
##  [](https://git-scm.com/docs/gitk#_examples)Examples

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt-gitkv2612includescsidriversscsi)gitk v2.6.12.. include/scsi drivers/scsi

Show the changes since version _v2.6.12_ that changed any file in the include/scsi or drivers/scsi subdirectories

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt-gitk--since2weeksago--gitk)gitk --since="2 weeks ago" -- gitk

Show the changes during the last two weeks to the file _gitk_. The "--" is necessary to avoid confusion with the **branch** named _gitk_

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt-gitk--max-count100--all--Makefile)gitk --max-count=100 --all -- Makefile

Show at most 100 changes made to the file _Makefile_. Instead of only looking for changes in the current branch look in all branches.
##  [](https://git-scm.com/docs/gitk#_files)Files
User configuration and preferences are stored at:
  * `$XDG_CONFIG_HOME/git/gitk` if it exists, otherwise
  * `$HOME/.gitk` if it exists


If neither of the above exist then `$XDG_CONFIG_HOME/git/gitk` is created and used by default. If _$XDG_CONFIG_HOME_ is not set it defaults to `$HOME/.config` in all cases.
##  [](https://git-scm.com/docs/gitk#_history)History
Gitk was the first graphical repository browser, written by Paul Mackerras in Tcl/Tk.
_gitk_ is actually maintained as an independent project, but stable versions are distributed as part of the Git suite for the convenience of end users.
`gitk-git/` comes from Johannes Sixt’s gitk project:
```
https://github.com/j6t/gitk
```

##  [](https://git-scm.com/docs/gitk#_see_also)SEE ALSO

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt-qgit1)_qgit(1)_

A repository browser written in C++ using Qt.

[](https://git-scm.com/docs/gitk#Documentation/gitk.txt-tig1)_tig(1)_

A minimal repository browser and Git tool output highlighter written in C using Ncurses.
##  [](https://git-scm.com/docs/gitk#_git)GIT
Part of the [git[1]](https://git-scm.com/docs/git) suite
### gitk
[About this site](https://git-scm.com/site)
Patches, suggestions, and comments are welcome.
Git is a member of [Software Freedom Conservancy](https://git-scm.com/sfc)
